# Model Inspector
> Inspect machine learning models


I developed this library primarily for generating model visualizations that I can use in teaching machine learning. I'd love for it to grow into a deeper library that is useful for practitioners as well.

See the [docs](https://gsganden.github.io/model_inspector/), especially for the [inspect module](https://gsganden.github.io/model_inspector/inspect.html), for API details and examples.

## Install

`pip install model_inspector`
